@@ -17,13 +17,13 @@
 
 #define QT_FEATURE_webengine_pepper_plugins 1
 
-#define QT_FEATURE_webengine_proprietary_codecs -1
+#define QT_FEATURE_webengine_proprietary_codecs 1
 
 #define QT_FEATURE_webengine_kerberos -1
 
 #define QT_FEATURE_webengine_webrtc 1
 
-#define QT_FEATURE_webengine_webrtc_pipewire -1
+#define QT_FEATURE_webengine_webrtc_pipewire 1
 
 #define QT_FEATURE_webengine_full_debug_info -1
 
